#
# spec file for package python-python-jenkins
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014 Thomas Bechtold <thomasbechtold@jpberlin.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-jenkins
Version:        1.8.0
Release:        2.5
Summary:        Python bindings for the remote Jenkins API
License:        BSD-3-Clause
URL:            https://opendev.org/jjb/python-jenkins
Source:         https://files.pythonhosted.org/packages/source/p/python-jenkins/python-jenkins-%{version}.tar.gz
# https://bugs.launchpad.net/python-jenkins/+bug/1971524
Patch0:         python-python-jenkins-no-mock.patch
# PATCH-FIX-OPENSUSE Upstream are arguing about version parsing, use the
# underlying parts of LegacyVersion from packaging pre-removal
Patch1:         use-parts-of-legacy-version.patch
BuildRequires:  %{python_module cmd2}
BuildRequires:  %{python_module multi_key_dict}
BuildRequires:  %{python_module pbr >= 0.8.2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests-mock >= 1.4}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module testscenarios}
BuildRequires:  %{python_module urllib3 < 2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(krb5-gssapi)
Requires:       python-multi_key_dict
Requires:       python-pbr
Requires:       python-requests
Requires:       python-six >= 1.3.0
Requires:       python-urllib3 < 2
Provides:       python-jenkins = %{version}
Obsoletes:      python-jenkins < %{version}
BuildArch:      noarch
%python_subpackages

%description
This package provides Python bindings for the Jenkins Remote
API. It currently supports management of:
 * Project configuration
 * Build control
 * Slave node configuration

%prep
%autosetup -p1 -n python-jenkins-%{version}

sed -i '1{\@^#!%{_bindir}/env python@d}' jenkins/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v tests

%files %{python_files}
%license COPYING
%doc README.rst
%{python_sitelib}/jenkins
%{python_sitelib}/python_jenkins-%{version}*-info

%changelog
* Mon Jul 24 2023 Steve Kowalik <steven.kowalik@suse.com>
- Pin {Build,}Requires on urllib3 to < 2.
* Mon Apr 17 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.0:
  * Add retrieval of stages of artifacts
  * Switch links to opendev.org
  * Allow build number to be a string
  * Use fullname in get_job_info_regex
- Add patch use-parts-of-legacy-version.patch:
  * Use underpining parts of LegacyVersion pre-removal.
* Wed May  4 2022 pgajdos@suse.com
- added patches
  fix https://bugs.launchpad.net/python-jenkins/+bug/1971524
  + python-python-jenkins-no-mock.patch
* Mon Mar 15 2021 Markéta Machová <mmachova@suse.com>
- we don't need stestr to run tests
  * which enables the tests again
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 1.7.0
  * Include placeholder tasks in get\_running\_builds
  * Fix reconfig\_credential() to send the xml data
  * new method: create\_folder (with tests)
  * new method: check\_jenkinsfile\_syntax (with tests)
  * Update docs building job
  * upsert\_job
* Thu Aug  1 2019 pgajdos@suse.com
- version update to 1.5.0
  * Remove pin on mock module
  * Update jobs
  * Make get\_job\_info fetch\_all\_builds work with jobs in folders
  * OpenDev Migration Patch
  * When updating jobs the response body may be empty
  * Add Python 3.6 classifier to setup.cfg
  * add python 3.6 unit test job
* Tue May 14 2019 Jonathan <jharker@suse.com>
- Fix dependencies for version 1.4.0
* Tue Dec 11 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 1.4.0:
  * Update min tox version to 2.0
  * Request multiple folder levels at once in get\_all\_jobs
  * Replace build\_jobs\_list\_responses with actual Jenkins responses
  * Clean up job/folder path handling
  * Test requested URLs in test\_getall
  * Make jjb-tox-cross-jenkins-job-builder voting
  * Allow adding extra HTTP headers to Jenkins requests
* Tue Sep  4 2018 dmueller@suse.com
- update to 1.2.1:
  * Revert "detect and respect http redirects"
  * Revert "Avoid empty body failure on HEAD requests"
  * Avoid empty body failure on HEAD requests
  * Fix item being ignored in get\_info
  * detect and respect http redirects
  * Fix run\_script method
  * Adopt use of pre-commit hooks
  * Adds support for executing Groovy scripts on jenkins nodes
  * Allow use of unicode job names
  * Added pypy-dev to bindep.txt
  * Fix run\_scripts() API
  * fix tox python3 overrides
  * Selectively mock requests\_kerberos import
  * Ensure timeout exceptions are re-raised during auth attempts
  * Revert "Do not require requests-kerberos for tests"
  * Freeze cmd2 library on python2
  * Update URLS that require depth or tree filters
  * README: mention #openstack-jjb channel
  * Do not require requests-kerberos for tests
  * Fix: send proxy as empty dict
  * Add functions to retrieve more data from Jenkins
  * Update to \_response\_handler
  * Trivial: Update pypi url to new url
  * add get\_queue\_item() method
  * build\_job: return queue item identifier
  * add jenkins\_request() method
  * Use proper code highlight in docs
  * Fix docstrings params
  * Adds support for wiping out a job's workspace
  * Adds support for multi-select build parameters
  * Adds support for deleting builds
  * enable cross testing with jenkins-job-builder
  * Improve SSL support with requests lib
  * Enables use of PYTHONHTTPSVERIFY override
  * Adding pypy to bindep test profile
  * Added folder support in views keeping backward compatibility and added tests for it
  * Add EMPTY\_FOLDER\_XML str to match docs
  * build\_job: fix grammar in comment
  * Replace testr with stestr
  * This Allow to include folders in jobs list when calling get\_all\_jobs() method. Closes-Bug: #1731903
  * repair .gitgnore
  * Migration to using requests
  * trivial:  modify spelling error of version
  * modify version spelling errors
  * Pass form data as body instead of in the url
  * get\_build\_console\_output: fix docs for "number" parameter
  * Sanitize url in get\_info() function
  * get\_job\_name: fix grammar in comment
  * doc: add get\_job\_config() example
  * create\_node: avoid double-encoding
  * Add py35 to tox envlist
- run tests
* Wed Jul 18 2018 tchvatal@suse.com
- Depend on python-rpm-macros
* Mon Sep 25 2017 dmueller@suse.com
- convert to singlespec
* Fri Apr 28 2017 tbechtold@suse.com
  update to version 0.4.14
  * get_running_builds failed when server has a path
  * Move other-requirements.txt to bindep.txt
  * Add optional kerberos support
  * Allow to wait for jenkins to enter normal operation
  * Remove discover from test-requirements
  * Fixed a minor typo in example of Python-jenkins
  * Fix relative import in kerberos support for python3
  * Changes get_job_info to get_build_info
  * url-proof scripts passed to run_script
  * Do not force DeprecationWarning to be displayed
  * Add support for handling promotions
  * Use standard cover setup
  * Adds possibility to retrieve all jobs from the view specified
  * Setup required packages with bindep
  * Make the kerberos support python3 ready
  * remove cap on pbr
  * Fetch all builds from a job
  * Remove redundant 'the'
  * add get_whoami()
- Use pypi.io as Source url
* Thu May 12 2016 tbechtold@suse.com
- Add missing Requires for python-setuptools
* Fri Feb 26 2016 tbechtold@suse.com
- Rename python-jenkins to python-python-jenkins. It's openSUSE
  policy to use python-$pypi name.
* Sun Jan  3 2016 tbechtold@suse.com
- update to 0.4.12:
  * Drop py33 support
  * Fixed create_node() Error
  * Deprecated tox -downloadcache option removed
  * Use TestWithScenarios to add additional url tests
  * Change repositories from stackforge to openstack
  * Update .gitreview for new namespace
* Fri Oct 30 2015 tbechtold@suse.com
- update to 0.4.11:
  * Handle depth errors in get_running_builds
  * Use str as base class for PluginVersion
  * Support ability to install plugins
  * Provider helper classes for plugin data management
  * Allow setting the next build number
  * Adds Cloudbees folder plugin support
  * Add function to get running builds
  * Change order of tox envs for testr
  * Add support for quiet down
  * fix get version example
  * remove support for python 2.6
  * Separate tests in separate files and classes
  * Create module member index from autodoc
  * Fix timeout function and add capturing of messages on failure
  * Stop specifying requirements.txt in tox.ini
  * Wrap url building with helper method
  * Rework the examples
  * Add socket timeout tests and helpers
- adjust Requires according to requirements.txt
* Tue Aug  4 2015 tbechtold@suse.com
- Add COPYING and README.rst as %%doc files
* Fri Jul 31 2015 tbechtold@suse.com
- update to 0.4.8:
  * Fix tests on python 2.6 and mark as deprecated
  * Remove unneeded wrapping of imports
  * Support scriptText api to execute groovy scripts on the server
  * Creates ability to work with views in jenkins
  * fix passing of byte object to url request method
  * requirements: pin pbr>=0.8.2,<2.0
  * Ensure request data is in the correct format
  * Ensure data is utf-8 encoded
  * Modify tests to exercise Request on python3
  * Add decode to utf8 for python 3.x
  * Fix examples
  * Add utf8 to headers
  * Add a get_nodes method
* Wed Mar 11 2015 tbechtold@suse.com
- update to 0.4.5:
  * Add get_job_info_regex method to get info about a set of jobs
  * Set the server connection timeout to same as socket timeout
  * Consolidate raising identical exceptions
  * Add a jobs_count method
  * Doc Update: Fix formatting for inclusion of README.rst
  * Doc Change: update supported python versions
  * Add BadHTTPException
  * Fix incorrect indentation
  * Don't return None on unhandled http errors
  * Use empty crumb on empty response
  * Don't assume we get a valid response
  * Update and clean up docs
  * Add a default http timeout for connections to jenkins
  * Eliminate redundant calls to assert_job_exists()
  * Raise an exception on 404
  * testtools requires unittest2
  * Fix cancel_queue() method
  * Fix enable_node and disable_node methods
  * Handle job and node names that contain spaces
  * Workflow documentation is now in infra-manual
  * fix typo, must be 'classifier' to appear on pypi.python.org
  * Yield HTTPError reason on open error
  * fix auth with long username or password
  * Add a readme and make it appear on pypi.python.org
  * Add get_plugins_info and get_plugin_info methods
  * generate a code coverage html report
  * add get_version method
  * exclude tests from code coverage report
  * Setup pbr versioning for docs
  * Support node configuration
  * Fix it so build_job triggers a build
  * Rename doc environment to docs
  * Enabled hacking check H404
  * Add MANIFEST.in
  * Six is a runtime requirement not a test req
  * Update version info
  * Fix `tox -e doc` duplicate id error
  * Use pbr, pep8 checks & fixes, add "doc" tox target
  * make JSON depth response configurable
  * Add a gitreview file
  * Adds assert_node_exists()
  * Speed up job existence tests by fetching less info
  * Fix remaining PEP8 errors in docstrings
  * Fix hacking docstring warnings
  * Make it work on Python 3
  * 100%% test coverage
  * Add support for measuring coverage
  * Support node startup with the JNLP Launcher
  * Add .gitignore
  * Clarify job_exists() error messages
  * Doc fixes
  * Wrap tests and linting with tox
  * David Strauss 2014-03-06 Fedora 19+ has packages, too
  * Fedora 19+ has packages, too
  * [soren] Add fixes for crumb addition to post requests
  * Add bug metadata
  * Change method name to reflect behaviour
  * Recycle crumb. Apparently, it's not a nonce
  * Attempt to fetch a crumb (needed if CSRF protection is enabled)
  * Release 0.2.1
  * speed up job existence test by fetching less informations
  * Add rename_job()
  * speed up job existence test by fetching less informations
  * Add rename_job()
  * Add ability to fetch raw console text for build
  * Antoine Musso:
  * overhaul the sphinx documentation
  * pass pep8 on all files
  * Add support for a rename_job() call
  * Merged new node management features including using SSH and
    Windows slaves plus cancel job/queue methods
  * Add additional methods:
  * Merged bug fix and tests for job names with spaces
  * Open for 0.3 development
- update Requires
* Mon Apr 21 2014 thomasbechtold@jpberlin.de
- Initial packaging of python-jenkins.
